@@ -52,6 +52,14 @@ PathwayConstructor <- R6::R6Class(
     validate = function() {
       private$cdmInterface$validate()
       
+      if (private$settings$minEraDuration > private$settings$minPostCombinationDuration) {
+        warning("The `minPostCombinationDuration` is set lower than the `minEraDuration`, this might result in unexpected behavior")
+      }
+      
+      if (private$settings$minEraDuration > private$settings$combinationWindow) {
+        warning("The `combinationWindow` is set lower than the `minEraDuration`, this might result in unexpected behavior")
+      }
+      
       errorMessages <- checkmate::makeAssertCollection()
       
       checkmate::assertCharacter(
@@ -193,6 +201,8 @@ PathwayConstructor <- R6::R6Class(
         minEraDuration = private$settings$minEraDuration
       )
       
+      private$checkCohortTable()
+      
       private$andromeda$cohortTable <- private$andromeda$cohortTable %>%
         dplyr::rename(
           cohortId = "cohort_definition_id",
@@ -283,6 +293,20 @@ PathwayConstructor <- R6::R6Class(
       minPostCombinationDuration = 30,
       filterTreatments = "First",
       maxPathLength = 5
-    )
+    ),
+    
+    ## Methods ----
+    checkCohortTable = function() {
+      cohortTableHead <- private$andromeda[["cohortTable"]] %>%
+        head() %>%
+        dplyr::collect()
+      
+      assertions <- checkmate::makeAssertCollection()
+      checkmate::assertIntegerish(cohortTableHead$cohort_definition_id, add = assertions)
+      checkmate::assertIntegerish(cohortTableHead$subject_id, add = assertions)
+      checkmate::assertDate(cohortTableHead$cohort_start_date, add = assertions)
+      checkmate::assertDate(cohortTableHead$cohort_end_date, add = assertions)
+      checkmate::reportAssertions(assertions)
+    }
   )
 )
